#!/opt/imunify360/venv/bin/python3
"""
Script for internal use in cron update scripts.

This script detects when parent call was maid from cron job and
apply the random delay in 60 minutes
"""

import os
import psutil
import random
import time

MAX_SLEEP_TIME = 3600


def is_current_process_cron_child():
    pid = os.getpid()
    try:
        process = psutil.Process(pid)
        parents = process.parents()

        # True for cron cronie anacron and etc..
        return any(is_cron(proc.name().lower()) for proc in parents)
    except psutil.NoSuchProcess:
        print("Unable to determine parent process ID.")
        return False


def is_cron(proc_name: str):
    return "cron" in proc_name and not "imunify" in proc_name


def sleep_in_cron():
    try:
        if is_current_process_cron_child():
            sleep_time = random.randint(0, MAX_SLEEP_TIME)
            print(f"Wait for {sleep_time} seconds before starting updates")
            time.sleep(sleep_time)
        else:
            print("Not in cron, run update immediately")
    except Exception as e:
        print("An error occurred while waiting: ", e)


sleep_in_cron()
